import { useState, useEffect, useCallback } from 'react';
import '../utils/useSealedState.js';
import '../utils/useId.js';
import { a as _objectWithoutPropertiesLoose, b as _objectSpread } from '../chunk-397c8002.js';
import '../utils/useCreateElement.js';
import '../system/SystemContext.js';
import '../system/useToken.js';
import '../system/useOptions.js';
import '../system/useProps.js';
import '../chunk-2f16e450.js';
import '../chunk-56719312.js';
import { unstable_createHook } from '../utils/createHook.js';
import { unstable_createComponent } from '../utils/createComponent.js';
import { useBox } from '../Box/Box.js';
import { a as useAllCallbacks } from '../chunk-a259d6a5.js';
import { useHiddenState } from './HiddenState.js';

function cx() {
  for (var _len = arguments.length, classes = new Array(_len), _key = 0; _key < _len; _key++) {
    classes[_key] = arguments[_key];
  }

  return classes.filter(Boolean).join(" ") || undefined;
}

var useHidden = unstable_createHook({
  name: "Hidden",
  compose: useBox,
  useState: useHiddenState,
  keys: ["unstable_animated"],
  useProps: function useProps(options, _ref) {
    var htmlOnTransitionEnd = _ref.onTransitionEnd,
        htmlClassName = _ref.className,
        htmlStyle = _ref.style,
        htmlProps = _objectWithoutPropertiesLoose(_ref, ["onTransitionEnd", "className", "style"]);

    var _React$useState = useState(options.visible),
        delayedVisible = _React$useState[0],
        setDelayedVisible = _React$useState[1];

    useEffect(function () {
      if (options.unstable_animated && options.visible) {
        setDelayedVisible(options.visible);
      }
    }, [options.visible, options.unstable_animated]);
    var onTransitionEnd = useCallback(function () {
      if (options.unstable_animated && !options.visible) {
        setDelayedVisible(options.visible);
      }
    }, [options.visible, options.unstable_animated]); // delays hiding

    var hidden = options.unstable_animated ? options.visible ? false : !delayedVisible : !options.visible; // delays showing

    var shouldAddHiddenClass = options.unstable_animated ? options.visible ? !delayedVisible : true : !options.visible;
    return _objectSpread({
      role: "region",
      id: options.unstable_hiddenId,
      className: cx(shouldAddHiddenClass && "hidden", htmlClassName),
      onTransitionEnd: useAllCallbacks(onTransitionEnd, htmlOnTransitionEnd),
      hidden: hidden
    }, hidden ? {
      style: _objectSpread({
        display: "none"
      }, htmlStyle)
    } : htmlStyle ? {
      style: htmlStyle
    } : {}, htmlProps);
  }
});
var Hidden = unstable_createComponent({
  as: "div",
  useHook: useHidden
});

export { Hidden, useHidden };
